pub struct ContainingBlockPositionInfo {
pub inline_start: Au,
pub inline_end: Au,
/* private fields */
}Expand description
FloatContext positions floats relative to the independent block formatting
context which contains the floating elements. The Fragment tree positions
elements relative to their containing blocks. This data structure is used to
help map between these two coordinate systems.
Fields
inline_start: AuThe distance from the inline start position of the float containing independent formatting context and the inline start of this containing block.
inline_end: AuThe offset from the inline start position of the float containing independent formatting context to the inline end of this containing block.
Implementations
Sourceimpl ContainingBlockPositionInfo
impl ContainingBlockPositionInfo
pub fn new_with_inline_offsets(inline_start: Au, inline_end: Au) -> Self