FloatContext

Struct FloatContext 

pub struct FloatContext {
    pub bands: FloatBandTree,
    pub ceiling_from_floats: Au,
    pub ceiling_from_non_floats: Au,
    pub containing_block_info: ContainingBlockPositionInfo,
    pub clear_inline_start_position: Au,
    pub clear_inline_end_position: Au,
}
Data kept during layout about the floats in a given block formatting context.

This is a persistent data structure. Each float has its own private copy of the float context, although such copies may share portions of the bands tree.

Fields

bands: FloatBandTree

A persistent AA tree of float bands.

This tree is immutable; modification operations return the new tree, which may share nodes with previous versions of the tree.

ceiling_from_floats: Au

The block-direction “ceiling” defined by the placement of other floated content of this FloatContext. No new floats can be placed at a lower block start than this value.

ceiling_from_non_floats: Au

The block-direction “ceiling” defined by the placement of non-floated content that precedes floated content in the document. Note that this may actually decrease as content is laid out in the case that content overflows its container.

containing_block_info: ContainingBlockPositionInfo

Details about the position of the containing block relative to the independent block formatting context that contains all of the floats this FloatContext positions.

clear_inline_start_position: Au

The (logically) lowest margin edge of the last inline-start float.

clear_inline_end_position: Au

The (logically) lowest margin edge of the last inline-end float.

Implementations

Source

impl FloatContext

pub fn new(max_inline_size: Au) -> Self

Returns a new float context representing a containing block with the given content inline-size.

pub fn set_ceiling_from_non_floats(&mut self, new_ceiling: Au)

(Logically) lowers the ceiling to at least new_ceiling units.

If the ceiling is already logically lower (i.e. larger) than this, does nothing.

pub fn add_float(&mut self, new_float: &PlacementInfo) -> LogicalVec2<Au>

Places a new float and adds it to the list. Returns the start corner of its margin box.