Structs
- Text
Security Transform - Text
Transformation - This is an iterator that consumes a char iterator and produces character transformed
by the given CSS
text-transformvalue. It currently does not supporttext-transform: capitalizebecause Unicode segmentation libraries do not support streaming input one character at a time. - Whitespace
Collapse