Module text_transform

Module text_transform 

Logic for text transform in inline formatting contexts

Inline formatting contexts do a variety of text transformations on their text content including white space collapsing, application of the text-transform CSS property, and application of the -webkit-text-security property. This module contains code to handle this as well as code to map from offsets in the original DOM node to the final IFC text and vice-versa.

Structs

CharacterTransformIteration
A single iteration in a pipeline of character iterators, that handle things like whitespace collapse and text-transform processing for text in an [InlineFormattingContext]. Each iteration can consume multiple characters and produce zero or more characters (up to 3). Consumption of characters greater than the characters produced by CharacterTransformIteration indicate that those characters have been collapsed.
OffsetMap
WhitespaceCollapse