pub struct TableBuilder {
pub incoming_rowspans: Vec<isize>,
/* private fields */
}Fields
incoming_rowspans: Vec<isize>An incoming rowspan is a value indicating that a cell in a row above the current row,
had a rowspan value other than 1. The values in this array indicate how many more
rows the cell should span. For example, a value of 0 at an index before current_x()
indicates that the cell on that column will not span into the next row, and at an index
after current_x() it indicates that the cell will not span into the current row.
A negative value means that the cell will span all remaining rows in the row group.
As each column in a row is processed, the values in this vector are updated for the next row.
Implementations
Sourceimpl TableBuilder
impl TableBuilder
pub fn new_for_tests() -> Self
pub fn last_row_index_in_row_group_at_row_n(&self, n: usize) -> usize
pub fn finish(self) -> Table
pub fn start_row(&mut self)
pub fn end_row(&mut self)
Sourcepub fn add_cell(&mut self, cell: ArcRefCell<TableSlotCell>)
pub fn add_cell(&mut self, cell: ArcRefCell<TableSlotCell>)
https://html.spec.whatwg.org/multipage/#algorithm-for-processing-rows Push a single cell onto the slot map, handling any colspans it may have, and setting up the outgoing rowspans.